@@ -3,7 +3,7 @@
 # $Id$
 
 # Galera library version
-VERSION="25.3.17"
+VERSION="25.3.19"
 
 get_cores()
 {
@@ -233,6 +233,13 @@ if [ -n "$WITH_SPREAD" ]; then CONFIGURE="yes"; fi
 
 if [ "$CONFIGURE" == "yes" ] && [ "$SCONS" != "yes" ]; then SCRATCH="yes"; fi
 
+#A workaround to fix MDEV-8249 on Centos 5.
+if [ -r /etc/redhat-release ]; then
+  if grep 'CentOS release 5' /etc/redhat-release > /dev/null 2>&1; then
+    DEBUG="yes"
+  fi
+fi
+
 # Be quite verbose
 #set -x
 
